<?php

/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package termico
 */

/**
 *
 * termico header
 */

function termico_check_header()
{
    $termico_header_style = function_exists('get_field') ? get_field('header_style') : NULL;
    $termico_default_header_style = get_theme_mod('choose_default_header', 'header-style-1');

    if ($termico_header_style == 'header-style-1') {
        termico_header_style_1();
    } elseif ($termico_header_style == 'header-style-2') {
        termico_header_style_2();
    } elseif ($termico_header_style == 'header-style-3') {
        termico_header_style_3();
    } else {

        /** default header style **/
        if ($termico_default_header_style == 'header-style-2') {
            termico_header_style_2();
        } elseif ($termico_default_header_style == 'header-style-3') {
            termico_header_style_3();
        } else {
            termico_header_style_1();
        }
    }
}
add_action('termico_header_style', 'termico_check_header', 10);

/**
 * header style 1 + default
 */

function termico_header_style_1()
{
    $termico_topbar_switch = get_theme_mod('termico_topbar_switch', false);
    $termico_cart_hide = get_theme_mod('termico_cart_hide', false);
    $termico_show_button = get_theme_mod('termico_show_button', false);
    $termico_show_cta = get_theme_mod('termico_show_cta', false);
    $termico_hamburger_hide = get_theme_mod('termico_hamburger_hide', false);
    $termico_show_header_search = get_theme_mod('termico_show_header_search', false);

    $termico_header_right = get_theme_mod('termico_header_right', false);
    $termico_menu_col =  $termico_header_right ? 'col-xl-6 col-lg-10 col-md-8 col-4' : 'col-xl-9 col-lg-10 col-md-8 col-4';
    $termico_menu_right =  $termico_header_right ? 'text-center' : 'text-right';

    if (rtl_enable()) {
        $btn_text = get_theme_mod('termico_button_text_rtl', 'Get A Quote');
    } else {
        $btn_text = get_theme_mod('termico_button_text', 'Get A Quote');
    }

    $btn_link = get_theme_mod('termico_button_link', '#');

?>

    <!-- header begin -->
    <header class="termico_header1">
        <div class="header-area black-bg">
            <div class="container-fluid">
                <div class="row no-gutters align-items-center">
                    <div class="col-xl-3 col-lg-2 col-md-4 col-8">
                        <div class="logo pt-20 pb-20">
                            <?php termico_header_logo(); ?>
                        </div>
                    </div>
                    <div class="<?php print esc_attr($termico_menu_col); ?>">
                        <div class="main-menu <?php print esc_attr($termico_menu_right); ?>">
                            <nav id="mobile-active">
                                <?php termico_header_menu(); ?>
                            </nav>
                        </div>
                        <div class="open-mobile-menu d-lg-none f-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>

                    <?php if (!empty($termico_header_right)) : ?>
                        <?php if (!empty($btn_link)) : ?>
                            <div class="col-xl-3 d-none d-xl-block">
                                <div class="header-btn ">
                                    <a class="theme-btn" href="<?php print esc_url($btn_link); ?>"><i class="fas fa-phone"></i> <?php print esc_html($btn_text); ?></a>
                                </div>
                            </div>
                        <?php endif;  ?>
                    <?php endif;  ?>
                </div>
            </div>
        </div>
    </header>

    <!-- slide-bar start -->
    <div class="fix">
        <div class="side-info">
            <button class="side-info-close"><i class="fal fa-times"></i></button>
            <?php termico_extra_info_mobile_logo(); ?>
            <div class="mobile-menu"></div>
            <?php termico_mobile_info(); ?>
        </div>
    </div>
    <div class="offcanvas-overlay"></div>
    <!-- slide-bar end -->

<?php
}

/**
 * header style 2 
 */
function termico_header_style_2()
{

    $termico_topbar_switch = get_theme_mod('termico_topbar_switch', false);
    $termico_show_button = get_theme_mod('termico_show_button', false);
    $termico_show_cta = get_theme_mod('termico_show_cta', false);
    $termico_hamburger_hide = get_theme_mod('termico_hamburger_hide', false);
    $termico_show_header_search = get_theme_mod('termico_show_header_search', false);
    $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

    $termico_support_label = get_theme_mod('termico_support_label', 'Available Support');
    $termico_support = get_theme_mod('termico_support', '24/7 Online Support');

    $termico_time_label = get_theme_mod('termico_time_label', 'Working Time');
    $termico_time = get_theme_mod('termico_time', '8:00AM - 12:00PM');

    $termico_mail_label = get_theme_mod('termico_mail_label', 'Get In Touch');
    $termico_mail = get_theme_mod('termico_mail', 'info@example.com');

    if (rtl_enable()) {
        $btn_text = get_theme_mod('termico_button_text_rtl', 'Get A Quote');
    } else {
        $btn_text = get_theme_mod('termico_button_text', 'Get A Quote');
    }

    $btn_link = get_theme_mod('termico_button_link', '#');

?>

    <header class="termico-header2">
        <div class="header-top">
            <!--Header Top Area -->
            <div class="container">
                <div class="row">
                    <div class="col-xl-3 col-lg-3 col-md-4 col-6 d-flex align-items-center">
                        <div class="header-logo">
                            <?php termico_header_logo(); ?>
                        </div>
                    </div>
                    <div class="col-xl-9 col-lg-9 col-md-8 col-6">
                        <div class="header-info d-flex f-right">
                            <?php if (!empty($termico_support)) : ?>
                                <div class="header-support">
                                    <div class="top-icon f-left"> <i class="fas fa-check-square"></i>
                                    </div>
                                    <div class="support-text fix">
                                        <ul>
                                            <li class="rubik"><?php print esc_html($termico_support_label); ?></li>
                                            <li class="opensens"><?php print esc_html($termico_support); ?></li>
                                        </ul>
                                    </div>
                                </div>
                            <?php endif;  ?>
                            <?php if (!empty($termico_time)) : ?>
                                <div class="header-support">
                                    <div class="top-icon f-left"> <i class="fas fa-clock"></i>
                                    </div>
                                    <div class="support-text fix">
                                        <ul>
                                            <li class="rubik"><?php print esc_html($termico_time_label); ?></li>
                                            <li class="opensens"><?php print esc_html($termico_time); ?></li>
                                        </ul>
                                    </div>
                                </div>
                            <?php endif;  ?>
                            <?php if (!empty($termico_mail)) : ?>
                                <div class="header-support d-none d-xl-block">
                                    <div class="top-icon f-left"> <i class="fas fa-envelope"></i>
                                    </div>
                                    <div class="support-text fix">
                                        <ul>
                                            <li class="rubik"><?php print esc_html($termico_mail_label); ?></li>
                                            <li class="opensens"><?php print esc_html($termico_mail); ?> </li>
                                        </ul>
                                    </div>
                                </div>
                            <?php endif;  ?>
                            <?php if (!empty($btn_link)) : ?>
                                <div class="get-in-btn d-none d-lg-block"> <a href="<?php print esc_url($btn_link); ?>" class="blue-btn"><?php print esc_html($btn_text); ?></a>
                                </div>
                            <?php endif;  ?>
                        </div>

                        <div class="open-mobile-menu d-lg-none f-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!--Header Top Area -->
        <!--Header Area -->
        <div class="header-bottom hp-1 d-none d-lg-block">
            <div class="container">
                <div class="main-header">
                    <div class="row">
                        <div class="col-xl-10 col-lg-10 col-md-10">
                            <div class="main-menu hp-1">
                                <nav id="mobile-active">
                                    <?php termico_header_menu(); ?>
                                </nav>
                            </div>
                        </div>
                        <?php if (!empty($termico_show_header_search)) : ?>
                            <div class="col-xl-2 col-lg-2 col-md-2 d-none d-md-block">
                                <div class="search-area text-right"> <a href="#" data-toggle="modal" data-target="#search-modal"><i class="fas fa-search"></i></a>
                                </div>
                            </div>
                        <?php endif;  ?>
                    </div>
                </div>
            </div>
        </div>
        <!--Header Area -->
    </header>

    <!-- slide-bar start -->
    <div class="fix">
        <div class="side-info">
            <button class="side-info-close"><i class="fal fa-times"></i></button>
            <?php termico_extra_info_mobile_logo(); ?>
            <div class="mobile-menu"></div>
            <?php termico_mobile_info(); ?>
        </div>
    </div>
    <div class="offcanvas-overlay"></div>
    <!-- slide-bar end -->

<?php
}

/**
 * header style 3
 */
function termico_header_style_3()
{
    $termico_topbar_switch = get_theme_mod('termico_topbar_switch', false);
    $termico_cart_hide = get_theme_mod('termico_cart_hide', false);
    $termico_show_button = get_theme_mod('termico_show_button', false);
    $termico_show_cta = get_theme_mod('termico_show_cta', false);
    $termico_hamburger_hide = get_theme_mod('termico_hamburger_hide', false);
    $termico_show_header_search = get_theme_mod('termico_show_header_search', false);
    $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

    if (rtl_enable()) {
        $btn_text = get_theme_mod('termico_button_text_rtl', 'Get A Quote');
    } else {
        $btn_text = get_theme_mod('termico_button_text', 'Get A Quote');
    }

    $btn_link = get_theme_mod('termico_button_link', '#');

?>
    <header class="header-transparent">
        <div class="logo-area">
            <div class="container">
                <div class="row">
                    <div class="col-6 col-lg-12">
                        <div class="logo-top text-left text-lg-center">
                            <?php termico_header_logo(); ?>
                        </div>
                    </div>
                    <div class="col-6 col-lg-12">
                        <div class="open-mobile-menu d-lg-none f-right">
                            <a href="javascript:void(0);">
                                <i class="fal fa-bars"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="menu-area d-none d-lg-block">
            <div class="container">
                <div class="row">
                    <div class="col-xl-9 col-lg-9">
                        <div class="main-menu style-3 text-left">
                            <nav id="mobile-active">
                                <?php termico_header_menu(); ?>
                            </nav>
                        </div>
                    </div>
                    <div class="col-xl-3 col-lg-3">
                        <div class="header-right text-right">
                            <?php termico_header_social_profiles(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>

    <!-- slide-bar start -->
    <div class="fix">
        <div class="side-info">
            <button class="side-info-close"><i class="fal fa-times"></i></button>
            <?php termico_extra_info_mobile_logo(); ?>
            <div class="mobile-menu"></div>
            <?php termico_mobile_info(); ?>
        </div>
    </div>
    <div class="offcanvas-overlay"></div>
    <!-- slide-bar end -->

<?php
}


// termico_mobile_info
function termico_mobile_info()
{
    // side info

    $termico_side_hide = get_theme_mod('termico_side_hide', true);
    $termico_mail_url = get_theme_mod('termico_mail_url', '#');
    $termico_mail_id = get_theme_mod('termico_side_mail_id', 'info@webmail.com');
    $termico_phone = get_theme_mod('termico_side_phone', '+876 864 764 764');
    $termico_address = get_theme_mod('termico_side_address', '12/A, Mirnada City Tower, NYC');
    $termico_side_info_title = get_theme_mod('termico_side_info_title', 'Contact Info');

    $termico_side_button_text = get_theme_mod('termico_side_button_text', 'Get A Quote');
    $termico_side_button_link = get_theme_mod('termico_side_button_link', '#');

?>

    <?php if (!empty($termico_side_hide)) : ?>
        <div class="contact-infos mt-30 mb-30">
            <div class="contact-list mb-30 mt-50">
                <?php if (!empty($termico_side_info_title)) : ?>
                    <h4><?php echo esc_html($termico_side_info_title); ?></h4>
                <?php endif; ?>
                <ul>
                    <?php if (!empty($termico_address)) : ?>
                        <li><i class="fal fa-map"></i><?php echo esc_html($termico_address); ?></li>
                    <?php endif; ?>

                    <?php if (!empty($termico_phone)) : ?>
                        <li><i class="fal fa-phone"></i><a href="tell:<?php echo esc_attr($termico_phone); ?>"><?php echo esc_html($termico_phone); ?></a></li>
                    <?php endif; ?>

                    <?php if (!empty($termico_mail_id)) : ?>
                        <li><i class="far fa-envelope"></i><a href="mailto:<?php echo esc_attr($termico_mail_url); ?>"><?php echo esc_html($termico_mail_id); ?></a></li>
                    <?php endif; ?>
                </ul>

                <?php if (!empty($termico_side_button_text)) : ?>
                    <div class="termico_button mt-30">
                        <a href="<?php print esc_url($termico_side_button_link); ?>" class="btn black-btn"><?php echo esc_html($termico_side_button_text); ?></a>
                    </div>
                <?php endif; ?>

                <div class="sidebar__menu--social s_sidebar_social">
                    <?php termico_header_social_profiles(); ?>
                </div>
            </div>
        </div>
    <?php endif; ?>

<?php }


function termico_extra_info_mobile_logo()
{
    $termico_extra_info_logo = get_theme_mod('termico_extra_info_logo', get_template_directory_uri() . '/img/logo/logo-black.png');

?>

    <?php if (!empty($termico_extra_info_logo)) : ?>
        <div class="logo-side mb-30">
            <a href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($termico_extra_info_logo); ?>" alt="<?php print esc_attr__('Logo', 'termico'); ?>">
            </a>
        </div>
    <?php endif; ?>


    <?php }


/** 
 * [termico_header_lang description]
 * @return [type] [description]
 */
function termico_header_lang_defualt()
{
    $termico_header_lang            = get_theme_mod('termico_header_lang', false);
    if ($termico_header_lang) : ?>

        <ul>
            <li><a href="#0" class="lang__btn"><?php print esc_html__('EN', 'termico'); ?> <i class="ti-arrow-down"></i></a>
                <?php do_action('termico_language'); ?>
            </li>
        </ul>

    <?php endif; ?>
<?php
}


/** 
 * [termico_language_list description]
 * @return [type] [description]
 */
function _termico_language($mar)
{
    return $mar;
}
function termico_language_list()
{

    $mar = '';
    $languages = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=desc');
    if (!empty($languages)) {
        $mar = '<ul>';
        foreach ($languages as $lan) {
            $active = $lan['active'] == 1 ? 'active' : '';
            $mar .= '<li class="' . $active . '"><a href="' . $lan['url'] . '">' . $lan['translated_name'] . '</a></li>';
        }
        $mar .= '</ul>';
    } else {
        //remove this code when send themeforest reviewer team
        $mar .= '<ul>';
        $mar .= '<li><a href="#">' . esc_html__('USA', 'termico') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('UK', 'termico') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('CA', 'termico') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('AU', 'termico') . '</a></li>';
        $mar .= ' </ul>';
    }
    print _termico_language($mar);
}
add_action('termico_language', 'termico_language_list');


// header logo
function termico_header_logo()
{
?>
    <?php
    $termico_logo_on = function_exists('get_field') ? get_field('is_enable_sec_logo') : NULL;
    $termico_logo = get_template_directory_uri() . '/assets/img/logo/logo.png';
    $termico_logo_white = get_template_directory_uri() . '/assets/img/logo/logo-black.png';

    $termico_site_logo = get_theme_mod('logo', $termico_logo);
    $termico_secondary_logo = get_theme_mod('seconday_logo', $termico_logo_white);
    ?>

    <?php
    if (has_custom_logo()) {
        the_custom_logo();
    } else {

        if (!empty($termico_logo_on)) { ?>
            <a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($termico_secondary_logo); ?>" alt="<?php print esc_attr('logo', 'termico'); ?>" />
            </a>
        <?php
        } else { ?>
            <a class="standard-logo-white" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($termico_site_logo); ?>" alt="<?php print esc_attr('logo', 'termico'); ?>" />
            </a>
    <?php
        }
    }
    ?>
<?php
}




/** 
 * [termico_header_social_profiles description]
 * @return [type] [description]
 */
function termico_header_social_profiles()
{
    $termico_topbar_fb_url             = get_theme_mod('termico_topbar_fb_url', '#');
    $termico_topbar_twitter_url       = get_theme_mod('termico_topbar_twitter_url', '#');
    $termico_topbar_instagram_url      = get_theme_mod('termico_topbar_instagram_url', '#');
    $termico_topbar_linkedin_url      = get_theme_mod('termico_topbar_linkedin_url', '#');
    $termico_topbar_youtube_url        = get_theme_mod('termico_topbar_youtube_url', '#');
?>
    <ul>
        <?php if (!empty($termico_topbar_fb_url)) : ?>
            <li><a href="<?php print esc_url($termico_topbar_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_topbar_twitter_url)) : ?>
            <li><a href="<?php print esc_url($termico_topbar_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_topbar_instagram_url)) : ?>
            <li><a href="<?php print esc_url($termico_topbar_instagram_url); ?>"><i class="fab fa-instagram"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_topbar_linkedin_url)) : ?>
            <li><a href="<?php print esc_url($termico_topbar_linkedin_url); ?>"><i class="fab fa-linkedin"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_topbar_youtube_url)) : ?>
            <li><a href="<?php print esc_url($termico_topbar_youtube_url); ?>"><i class="fab fa-youtube"></i></a></li>
        <?php endif; ?>
    </ul>
<?php
}


function termico_footer_social_profiles()
{
    $termico_footer_fb_url             = get_theme_mod('termico_footer_fb_url', '#');
    $termico_footer_twitter_url       = get_theme_mod('termico_footer_twitter_url', '#');
    $termico_footer_instagram_url      = get_theme_mod('termico_footer_instagram_url', '#');
    $termico_footer_linkedin_url        = get_theme_mod('termico_footer_linkedin_url', '#');
    $termico_footer_youtube_url        = get_theme_mod('termico_footer_youtube_url', '#');
?>
    <ul>
        <?php if (!empty($termico_footer_fb_url)) : ?>
            <li><a href="<?php print esc_url($termico_footer_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_footer_twitter_url)) : ?>
            <li><a href="<?php print esc_url($termico_footer_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_footer_instagram_url)) : ?>
            <li><a href="<?php print esc_url($termico_footer_instagram_url); ?>"><i class="fab fa-instagram"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_footer_linkedin_url)) : ?>
            <li><a href="<?php print esc_url($termico_footer_linkedin_url); ?>"><i class="fab fa-linkedin"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($termico_footer_youtube_url)) : ?>
            <li><a href="<?php print esc_url($termico_footer_youtube_url); ?>"><i class="fab fa-youtube"></i></a></li>
        <?php endif; ?>
    </ul>

<?php
}


/** 
 * [termico_header_menu description]
 * @return [type] [description]
 */
function termico_header_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location'    => 'main-menu',
        'menu_class'        => '',
        'container'         => '',
        'fallback_cb'       => 'Navwalker_Class::fallback',
        'walker'            => new Navwalker_Class
    ));
    ?>
<?php
}

/** 
 * [termico_header_menu left description]
 * @return [type] [description]
 */
function termico_header_left_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location'    => 'main-left-menu',
        'menu_class'        => '',
        'container'         => '',
        'fallback_cb'       => 'Navwalker_Class::fallback',
        'walker'            => new Navwalker_Class
    ));
    ?>
<?php
}

/** 
 * [termico_header_menu left description]
 * @return [type] [description]
 */
function termico_header_right_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location'    => 'main-right-menu',
        'menu_class'        => '',
        'container'         => '',
        'fallback_cb'       => 'Navwalker_Class::fallback',
        'walker'            => new Navwalker_Class
    ));
    ?>
<?php
}


/**
 * [termico_header_menu description]
 * @return [type] [description]
 */
function termico_mobile_menu()
{ ?>
    <?php
    $termico_menu = wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class'     => '',
        'container'      => '',
        'menu_id'        => 'mobile-menu-active',
        'echo'           => false
    ));

    $termico_menu = str_replace("menu-item-has-children", "menu-item-has-children has-children", $termico_menu);
    echo wp_kses_post($termico_menu);
    ?>
<?php
}

function termico_header_3_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location'    => 'main-menu',
        'menu_class'        => '',
        'container'         => '',
    ));
    ?>
<?php
}


/** 
 * [termico_footer_menu description]
 * @return [type] [description]
 */
function termico_footer_menu()
{

    wp_nav_menu(array(
        'theme_location'    => 'footer-menu',
        'menu_class'        => 'm-0',
        'container'         => '',
        'fallback_cb'       => 'Navwalker_Class::fallback',
        'walker'            => new Navwalker_Class
    ));
}


/**
 *
 * termico footer
 */
add_action('termico_footer_style', 'termico_check_footer', 10);

function termico_check_footer()
{
    $termico_footer_style = function_exists('get_field') ? get_field('footer_style') : NULL;
    $termico_default_footer_style = get_theme_mod('choose_default_footer', 'footer-style-1');


    if ($termico_footer_style == 'footer-style-1') {
        termico_footer_style_1();
    } elseif ($termico_footer_style == 'footer-style-2') {
        termico_footer_style_2();
    } elseif ($termico_footer_style == 'footer-style-3') {
        termico_footer_style_3();
    } else {

        /** default footer style **/
        if ($termico_default_footer_style == 'footer-style-2') {
            termico_footer_style_2();
        } elseif ($termico_default_footer_style == 'footer-style-3') {
            termico_footer_style_3();
        } else {
            termico_footer_style_1();
        }
    }
}

/**
 * footer  style_defaut
 */
function termico_footer_style_1()
{
    $_prefix = 'kindspa';

    $footer_bg_img = get_theme_mod('termico_footer_bg');
    $footer_social_switch = get_theme_mod('footer_social_switch', false);
    $termico_copyright_center = $footer_social_switch ? 'col-md-6' : 'col-md-12 text-center';
    $termico_footer_bg_url_from_page = function_exists('get_field') ? get_field('kindspa_footer_bg') : '';
    $termico_footer_bg_color_from_page = function_exists('get_field') ? get_field('kindspa_footer_bg_color') : '';
    $kindspa_footer_bottom_color_from_page = function_exists('get_field') ? get_field($_prefix . '_footer_bottom_color') : '';
    $footer_bg_color = get_theme_mod('termico_footer_bg_color');
    $termico_footer_copy_color = get_theme_mod('termico_footer_bottom_color');

    // bg image
    $bg_img = !empty($termico_footer_bg_url_from_page['url']) ? $termico_footer_bg_url_from_page['url'] : $footer_bg_img;
    // bg color
    $bg_color = !empty($termico_footer_bg_color_from_page) ? $termico_footer_bg_color_from_page : $footer_bg_color;
    $footer_bottom_color = !empty($kindspa_footer_bottom_color_from_page) ? $kindspa_footer_bottom_color_from_page : $termico_footer_copy_color;

    // footer_columns
    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 3);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-4 col-md-6';
            $footer_class[2] = 'col-xl-5 col-lg-5 col-md-6';
            $footer_class[3] = 'col-xl-3 col-lg-3 col-md-12';
            break;
        case '4':
            $footer_class[1] = 'col-xl-3 col-lg-4 col-md-6';
            $footer_class[2] = 'col-xl-3 col-lg-4 col-md-6 col-md-6';
            $footer_class[3] = 'col-xl-3 col-lg-3 col-md-6 d-lg-none d-xl-block';
            $footer_class[4] = 'col-xl-3 col-lg-4 col-md-6 d-lg-block';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer>
        <?php if (is_active_sidebar('footer-1') or is_active_sidebar('footer-2') or is_active_sidebar('footer-3') or is_active_sidebar('footer-4')) : ?>
            <!-- Footer Top Area Start -->
            <section class="footer-area black-bg pt-115 pb-80" data-background="<?php print esc_url($bg_img); ?>" data-bg-color="<?php print esc_attr($bg_color); ?>">
                <div class="container">
                    <div class="row">
                        <?php
                        if ($footer_columns < 3) {
                            print '<div class="col-xl-4 col-lg-4 col-md-6">';
                            dynamic_sidebar('footer-1');
                            print '</div>';

                            print '<div class="col-xl-5 col-lg-5 col-md-6">';
                            dynamic_sidebar('footer-2');
                            print '</div>';

                            print '<div class="col-xl-3 col-lg-3 col-md-12">';
                            dynamic_sidebar('footer-3');
                            print '</div>';
                        } else {
                            for ($num = 1; $num <= $footer_columns; $num++) {
                                if (!is_active_sidebar('footer-' . $num)) continue;
                                print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                dynamic_sidebar('footer-' . $num);
                                print '</div>';
                            }
                        }

                        ?>
                    </div>
                </div>
            </section>
            <!-- Footer Top Area End -->
        <?php endif; ?>

        <section class="footer-bottom pt-25 pb-25 theme-bg" data-bg-color="<?php print esc_attr($footer_bottom_color); ?>">
            <div class="container">
                <div class="row">
                    <div class="col-xl-12">
                        <div class="copyright text-center">
                            <h6><?php print termico_copyright_text(); ?></h6>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </footer>


<?php
}

/**
 * footer  style 2
 */
function termico_footer_style_2()
{
    $_prefix = 'kindspa';
    $footer_bg_img = get_theme_mod('termico_footer_bg');
    $termico_footer_logo_black = get_theme_mod('termico_footer_logo_black');
    $termico_copyright_center = $termico_footer_logo_black ? 'col-lg-4 offset-lg-4 col-md-6 text-right' : 'col-lg-12 text-center';
    $termico_footer_bg_url_from_page = function_exists('get_field') ? get_field('kindspa_footer_bg') : '';
    $termico_footer_bg_color_from_page = function_exists('get_field') ? get_field('kindspa_footer_bg_color') : '';
    $kindspa_footer_bottom_color_from_page = function_exists('get_field') ? get_field($_prefix . '_footer_bottom_color') : '';
    $footer_bg_color = get_theme_mod('termico_footer_bg_color');
    $termico_footer_copy_color = get_theme_mod('termico_footer_bottom_color');

    // bg image
    $bg_img = !empty($termico_footer_bg_url_from_page['url']) ? $termico_footer_bg_url_from_page['url'] : $footer_bg_img;
    // bg color
    $bg_color = !empty($termico_footer_bg_color_from_page) ? $termico_footer_bg_color_from_page : $footer_bg_color;
    $footer_bottom_color = !empty($kindspa_footer_bottom_color_from_page) ? $kindspa_footer_bottom_color_from_page : $termico_footer_copy_color;

    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-2-' . $num)) {
            $footer_columns++;
        }
    }



    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
            $footer_class[3] = 'col-xl-4 col-lg-6';
            break;
        case '4':
            $footer_class[1] = 'col-xl-3 col-lg-4 col-md-6 col-sm-12';
            $footer_class[2] = 'col-xl-3 col-lg-4 col-md-6 col-sm-12';
            $footer_class[3] = 'col-xl-3 col-lg-3 d-lg-none d-xl-block col-md-6 col-sm-12';
            $footer_class[4] = 'col-xl-3 col-lg-4 col-md-6 col-sm-12';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer class="hp-1">
        <?php if (is_active_sidebar('footer-2-1') or is_active_sidebar('footer-2-2') or is_active_sidebar('footer-2-3') or is_active_sidebar('footer-2-4')) : ?>
            <div class="footer-top pt-120 pb-90" data-background="<?php print esc_attr($bg_img); ?>" data-bg-color="<?php print esc_attr($bg_color); ?>">
                <div class="container">
                    <div class="row">
                        <?php
                        if ($footer_columns < 4) {
                            print '<div class="col-xl-3 col-lg-4 col-md-6 col-sm-12">';
                            dynamic_sidebar('footer-2-1');
                            print '</div>';

                            print '<div class="col-xl-3 col-lg-4 col-md-6 col-sm-12">';
                            dynamic_sidebar('footer-2-2');
                            print '</div>';

                            print '<div class="col-xl-3 col-lg-3 d-lg-none d-xl-block col-md-6 col-sm-12">';
                            dynamic_sidebar('footer-2-3');
                            print '</div>';

                            print '<div class="col-xl-3 col-lg-4 col-md-6 col-sm-12">';
                            dynamic_sidebar('footer-2-4');
                            print '</div>';
                        } else {
                            for ($num = 1; $num <= $footer_columns; $num++) {
                                if (!is_active_sidebar('footer-2-' . $num)) continue;
                                print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                dynamic_sidebar('footer-2-' . $num);
                                print '</div>';
                            }
                        }

                        ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="footer-copyright pt-30 pb-30" data-bg-color="<?php print esc_attr($footer_bottom_color); ?>">
            <div class="container">
                <div class="row">
                    <div class="col-xl-6 col-md-6 col-sm-12">
                        <div class="copyright style-1 mt-10"> <span><?php print termico_copyright_text(); ?></span>
                        </div>
                    </div>
                    <div class="col-xl-6 col-md-6 col-sm-12">
                        <div class="footer-social-link text-right style-1">
                            <?php termico_footer_social_profiles(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>

<?php
}


/**
 * footer  3
 */
function termico_footer_style_3()
{

    $_prefix = 'kindspa';

    $footer_bg_img = get_theme_mod('termico_footer_bg');
    $termico_footer_bg_url_from_page = function_exists('get_field') ? get_field($_prefix . '_footer_bg') : '';
    $termico_footer_bg_color_from_page = function_exists('get_field') ? get_field($_prefix . '_footer_bg_color') : '';
    $kindspa_footer_bottom_color_from_page = function_exists('get_field') ? get_field($_prefix . '_footer_bottom_color') : '';
    $footer_bg_color = get_theme_mod('termico_footer_bg_color');
    $termico_footer_copy_color = get_theme_mod('termico_footer_bottom_color');

    // bg image
    $bg_img = !empty($termico_footer_bg_url_from_page['url']) ? $termico_footer_bg_url_from_page['url'] : $footer_bg_img;
    // bg color
    $bg_color = !empty($termico_footer_bg_color_from_page) ? $termico_footer_bg_color_from_page : $footer_bg_color;
    $footer_bottom_color = !empty($kindspa_footer_bottom_color_from_page) ? $kindspa_footer_bottom_color_from_page : $termico_footer_copy_color;

    $footer_columns = 0;

    $footer_widgets = get_theme_mod('footer_widget_number', 1);

    for ($num = 1; $num <= $footer_widgets + 1; $num++) {
        if (is_active_sidebar('footer-3-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-xl-8 offset-xl-2 col-lg-10 offset-lg-1';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-sm-6 col-6';
            $footer_class[3] = 'col-xl-4 col-lg-6';
        case '4':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
            $footer_class[2] = 'col-xl-2 col-lg-6 col-sm-6 col-6';
            $footer_class[3] = 'col-xl-2 col-lg-6 col-sm-6 col-6';
            $footer_class[4] = 'col-xl-4 col-lg-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer class=" style-3">
        <section class="footer-area style-3 pt-120 pb-120" data-background="<?php print esc_attr($bg_img); ?>" data-bg-color="<?php print esc_attr($bg_color); ?>">
            <div class="container">
                <div class="row justify-content-center">
                    <div class="col-xl-8 col-lg-10 text-center">
                        <?php dynamic_sidebar('footer-3-1'); ?>
                    </div>
                </div>
            </div>
        </section>
        <section class="footer-bottom style-3 pt-25 pb-25" data-bg-color="<?php print esc_attr($footer_bottom_color); ?>">
            <div class="container">
                <div class="row">
                    <div class="col-xl-12">
                        <div class="copyright style-3 text-center">
                            <h6><?php print termico_copyright_text(); ?></h6>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </footer>

    <?php
}

function termico_copyright_text()
{
    if (rtl_enable()) {
        print get_theme_mod('termico_copyright_rtl', esc_html__('Copyright ©2022 ThemePure. All Rights Reserved', 'termico'));
    } else {
        print get_theme_mod('termico_copyright', esc_html__('Copyright ©2022 ThemePure. All Rights Reserved', 'termico'));
    }
}


/** 
 * [termico_breadcrumb_func description]
 * @return [type] [description]
 */
function termico_breadcrumb_func()
{

    $breadcrumb_class = '';
    $breadcrumb_show = 1;

    if (is_front_page() && is_home()) {
        $title = get_theme_mod('breadcrumb_blog_title', esc_html__('Blog', 'termico'));
        $breadcrumb_class = 'home_front_page';
    } elseif (is_front_page()) {
        $title = get_theme_mod('breadcrumb_blog_title', esc_html__('Blog', 'termico'));
        $breadcrumb_show = 0;
    } elseif (is_home()) {
        if (get_option('page_for_posts')) {
            $title = get_the_title(get_option('page_for_posts'));
        }
    } elseif (is_single() && 'post' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_blog_title_details_rtl', esc_html__('Blog', 'termico'));
        else
            $title = get_the_title();
    } elseif (is_single() && 'product' == get_post_type()) {
        $title = get_theme_mod('breadcrumb_product_details', esc_html__('Shop', 'termico'));
    } elseif (is_single() && 'bdevs-services' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_department_details_rtl', esc_html__('Services', 'termico'));
        else
            $title = get_theme_mod('breadcrumb_department_details', esc_html__('Services', 'termico'));
    } elseif (is_single() && 'bdevs-doctor' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_doctor_details_rtl', esc_html__('Doctor Details', 'termico'));
        else
            $title = get_theme_mod('breadcrumb_doctor_details', esc_html__('Doctor Details', 'termico'));
    } elseif (is_single() && 'bdevs-case_study' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_case_study_details_rtl', esc_html__('Gallery', 'termico'));
        else
            $title = get_theme_mod('breadcrumb_case_study_details', esc_html__('Gallery', 'termico'));
    } elseif (is_search()) {
        $title = esc_html__('Search Results for : ', 'termico') . get_search_query();
    } elseif (is_404()) {
        $title = esc_html__('Page not Found', 'termico');
    } elseif (function_exists('is_woocommerce') && is_woocommerce()) {
        $title = get_theme_mod('breadcrumb_shop', 'Shop ');
    } elseif (is_archive()) {
        $title = get_the_archive_title();
    } else {
        $title = get_the_title();
    }


    $_id = get_the_ID();
    if (is_single() && 'product' == get_post_type()) {
        $_id = wc_get_page_id('shop');
    } elseif (is_home() && get_option('page_for_posts')) {
        $_id = get_option('page_for_posts');
    } elseif (function_exists("is_shop")) {
        $_id = wc_get_page_id('shop');
    }


    $is_breadcrumb = function_exists('get_field') ? get_field('is_it_invisible_breadcrumb', $_id) : '';


    if (empty($is_breadcrumb) && $breadcrumb_show == 1) {

        $bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image', $_id) : '';
        $hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image', $_id) : '';
        $back_title = function_exists('get_field') ? get_field('breadcrumb_back_title', $_id) : '';

        // get_theme_mod
        $bg_img = get_theme_mod('breadcrumb_bg_img');


        if ($hide_bg_img) {
            $bg_img = '';
        } else {
            $bg_img = !empty($bg_img_from_page) ? $bg_img_from_page['url'] : $bg_img;
        } ?>

        <div class="breadcrumb-bg black-bg bg_img breadcrumb-spacing <?php print esc_attr($breadcrumb_class); ?>" data-overlay="5" data-background="<?php print esc_attr($bg_img); ?>">
            <div class="container">
                <div class="row">
                    <div class="col-xl-12">
                        <div class="page-title text-center">
                            <h2 class="breadcrumb-title"><?php echo wp_kses_post($title); ?></h2>
                        </div>
                    </div>
                </div>
            </div>
            <div class="container-fluid">
                <div class="breadcrumb-menu">
                    <?php termico_breadcrumb_callback(); ?>
                </div>
            </div>
        </div>

    <?php
    }
}
add_action('termico_before_main_content', 'termico_breadcrumb_func');


function termico_breadcrumb_callback()
{
    $args = array(
        'show_browse'   => false,
        'post_taxonomy' => array('product' => 'product_cat')
    );
    $breadcrumb = new Breadcrumb_Class($args);

    return $breadcrumb->trail();
}


// gru_search_form
function termico_search_form()
{ ?>

    <!-- Modal Search -->
    <div class="modal fade" id="search-modal" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                    <input type="search" name="s" class="main-search-input" value="<?php print esc_attr(get_search_query()) ?>" placeholder="<?php print esc_attr('Search Your Keyword...', 'termico'); ?>">
                    <button type="submit"> <i class="fa fa-search"></i>
                    </button>
                </form>
            </div>
        </div>
    </div>

<?php
}

add_action('termico_before_main_content', 'termico_search_form');

/**
 *
 * pagination
 */
if (!function_exists('termico_pagination')) {

    function _termico_pagi_callback($pagination)
    {
        return $pagination;
    }

    //page navegation
    function termico_pagination($prev, $next, $pages, $args)
    {
        global $wp_query, $wp_rewrite;
        $menu = '';
        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

        if ($pages == '') {
            global $wp_query;
            $pages = $wp_query->max_num_pages;

            if (!$pages)
                $pages = 1;
        }

        $pagination = array(
            'base' => add_query_arg('paged', '%#%'),
            'format' => '',
            'total' => $pages,
            'current' => $current,
            'prev_text' => $prev,
            'next_text' => $next,
            'type' => 'array'
        );

        //rewrite permalinks
        if ($wp_rewrite->using_permalinks())
            $pagination['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');

        if (!empty($wp_query->query_vars['s']))
            $pagination['add_args'] = array('s' => get_query_var('s'));

        $pagi = '';
        if (paginate_links($pagination) != '') {
            $paginations = paginate_links($pagination);
            $pagi .= '<ul>';
            foreach ($paginations as $key => $pg) {
                $pagi .= '<li>' . $pg . '</li>';
            }
            $pagi .= '</ul>';
        }

        print _termico_pagi_callback($pagi);
    }
}




// rtl_enable
function rtl_enable()
{
    $my_current_lang = apply_filters('wpml_current_language', NULL);
    $rtl_enable = get_theme_mod('rtl_switch', false);
    if ($my_current_lang  != 'en' && $rtl_enable) {
        return true;
    } else {
        return false;
    }
}

// header top bg color
function termico_breadcrumb_bg_color()
{
    $color_code = get_theme_mod('termico_breadcrumb_bg_color', '#222');
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-bg.gray-bg{ background: " . $color_code . "}";

        wp_add_inline_style('termico-breadcrumb-bg', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_breadcrumb_bg_color');

// breadcrumb-spacing top
function termico_breadcrumb_spacing()
{
    $color_code = get_theme_mod('termico_breadcrumb_spacing', '160px');
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ padding-top: " . $color_code . "}";

        wp_add_inline_style('termico-custom', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_breadcrumb_spacing');

// breadcrumb-spacing bottom
function termico_breadcrumb_bottom_spacing()
{
    $color_code = get_theme_mod('termico_breadcrumb_bottom_spacing', '160px');
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ padding-bottom: " . $color_code . "}";

        wp_add_inline_style('termico-custom', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_breadcrumb_bottom_spacing');


// TERMICO_THEME_color
function TERMICO_THEME_color()
{
    $color_code = get_theme_mod('termico_color_option', __('#e8d2b8', 'termico'));
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".border-btn:hover, .theme-btn, .black-btn:hover,.slider-active button:hover,.service-content a,.team-wrapper:hover .team-text,.b-cat a,.theme-bg,.brown-btn, .grey-btn:hover,.service-list a::before,.features-items .icon,.wpcf7-submit.theme-btn,.grid-wrapper::before,.service-arch-content .service-icon,.service-price-inner .pricing-amount,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.tagcloud a:hover,.blog-post-tag a:hover { background: " . $color_code . "}";

        $custom_css .= ".feature-icon i,.team-text span,.main-menu ul li ul.sub-menu li:hover > a,.main-menu ul li:hover > a,.single-slider.style-3 h6,.header-right li a:hover,.main-menu.style-3 li:hover a,.main-menu.style-3 li .sub-menu li a:hover,.service-list .icon i,.service-caption .service-pricing span,.breadcrumb-menu ul li a,.breadcrumb-menu li,.service-arch-content ul li a.brown-color,.service-arch-content h4:hover,.widget-posts-title a:hover,.post-meta span a:hover,.blog-title a:hover,.widget li a:hover,.contact-form .name::before,.contact-form .email::before,.contact-form .phone::before,.contact-form .service::before,.contact-form .massage::before { color: " . $color_code . "}";

        $custom_css .= ".header-btn a,.about-border ,.border-btn,.footer-contact form button,.brown-btn, .grey-btn:hover,.widget,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.blog-post-tag a:hover,.comment-form textarea:focus,.comment-form input:focus{ border-color: " . $color_code . "}";

        wp_add_inline_style('termico-custom', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'TERMICO_THEME_color');

// termico_sec_color_option
function termico_sec_color_option()
{
    $color_code = get_theme_mod('termico_sec_color_option', __('#ec5598', 'termico'));
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".main-header,.blue-btn:hover, .pink-btn,.gallery-image::before,.appointment-img::before,.intro-content ul li:hover i,.intro-img a:hover,.pricing-item.active { background: " . $color_code . "}";

        $custom_css .= ".blog-content h3 a:hover,.top-icon i,.slider-content.hp-1 h6,.appointment-intro.hp-1 h6,.single-content span,.intro-content ul li i,.intro-img a,.single-item h5,.pricing-list li .fa-check,.post-meta span i,.post-text blockquote footer,.contact i{ color: " . $color_code . "}";

        $custom_css .= ".cfdf{ border-color: " . $color_code . "}";

        wp_add_inline_style('termico-custom', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_sec_color_option');

// termico_third_color_option
function termico_third_color_option()
{
    $color_code = get_theme_mod('termico_third_color_option', '#6a1b9a');
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".blue-btn, .pink-btn:hover,.single-content .team-social li a:hover{ background: " . $color_code . "}";

        $custom_css .= ".main-menus nav ul li.active a{ color: " . $color_code . "}";

        $custom_css .= ".video-links a:hover{ border-color: " . $color_code . "}";
        wp_add_inline_style('termico-custom', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_third_color_option');


// scrollup
function termico_scrollup_switch()
{
    $scrollup_switch = get_theme_mod('termico_scrollup_switch', false);
    wp_enqueue_style('termico-custom', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($scrollup_switch) {
        $custom_css = '';
        $custom_css .= "#scrollUp{ display: none !important;}";

        wp_add_inline_style('termico-scrollup-switch', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_scrollup_switch');



// body font
function termico_body_font()
{
    $termico_body_font = get_theme_mod('termico_body_font', "'Rubik', sans-serif");
    wp_enqueue_style('termico-body-font', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($termico_body_font != '') {
        $customs_css = '';
        $customs_css .= "body{ font-family: " . $termico_body_font . "}";
        wp_add_inline_style('termico-body-font', $customs_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_body_font');

// Heading font
function termico_heading_font()
{
    $termico_heading_font = get_theme_mod('termico_heading_font', "'Domine', serif");
    wp_enqueue_style('termico-heading-font', TERMICO_THEME_CSS_DIR . 'termico-custom.css', array());
    if ($termico_heading_font != '') {
        $custom_css = '';
        $custom_css .= "h1,h2,h3,h4,h5,h6{ font-family: " . $termico_heading_font . "}";
        wp_add_inline_style('termico-heading-font', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'termico_heading_font');



function termico_kses_intermediate($string = '')
{
    return wp_kses($string, termico_get_allowed_html_tags('intermediate'));
}


function termico_get_allowed_html_tags($level = 'basic')
{
    $allowed_html = [
        'b' => [],
        'i' => [],
        'u' => [],
        'em' => [],
        'br' => [],
        'abbr' => [
            'title' => [],
        ],
        'span' => [
            'class' => [],
        ],
        'strong' => [],
        'a' => [
            'href' => [],
            'title' => [],
            'class' => [],
            'id' => []
        ]
    ];

    return $allowed_html;
}
